from setuptools import setup, find_packages

setup(name='get-titles-package',
      version='3.0',
      author='Pawel Helisz',
      author_email='252779@student.pwr.edu.pl',
      packages=find_packages(),
      )
